@@ -696,14 +696,15 @@ fr_command_rar_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_rar_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES | FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER;
-	if (is_program_in_path ("rar"))
+	if (is_program_available ("rar", check_command))
 		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_CREATE_VOLUMES;
-	else if (is_program_in_path ("unrar"))
+	else if (is_program_available ("unrar", check_command))
 		capabilities |= FR_COMMAND_CAN_READ;
 
 	/* multi-volumes are read-only */
@@ -714,6 +715,14 @@ fr_command_rar_get_capabilities (FrCommand  *comm,
 }
 
 
+static const char *
+fr_command_rar_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return PACKAGES ("rar,unrar");
+}
+
+
 static void
 fr_command_rar_class_init (FrCommandRarClass *class)
 {
@@ -733,6 +742,7 @@ fr_command_rar_class_init (FrCommandRarClass *class)
 	afc->handle_error     = fr_command_rar_handle_error;
 	afc->get_mime_types   = fr_command_rar_get_mime_types;
 	afc->get_capabilities = fr_command_rar_get_capabilities;
+	afc->get_packages     = fr_command_rar_get_packages;
 }
 
 
